package com.ynet.life.util;

import com.ynet.gene.core.Context;
import com.ynet.gene.data.DataElement;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

/* loaded from: com_ynet_life_util.jar:com/ynet/life/util/DataCache.class */
public class DataCache implements Serializable {
    private int index = 0;
    private List datas;
    private int Length;

    public DataCache(int length) {
        this.Length = length;
        this.datas = new ArrayList(length);
    }

    public synchronized void setData(String key, Object obj) {
        CacheEntry entry = new CacheEntry(key, obj);
        if (this.index < this.Length) {
            this.datas.add(entry);
            this.index++;
            return;
        }
        long tmpTime = Long.MAX_VALUE;
        int replaceIdx = 0;
        for (int i = 0; i < this.datas.size(); i++) {
            CacheEntry tmpEntry = (CacheEntry) this.datas.get(i);
            if (tmpEntry.getAddTime() < tmpTime) {
                tmpTime = tmpEntry.getAddTime();
                replaceIdx = i;
            }
        }
        this.datas.set(replaceIdx, entry);
    }

    public synchronized Object getData(String key) {
        for (int i = 0; i < this.datas.size(); i++) {
            CacheEntry cacheEntry = (CacheEntry) this.datas.get(i);
            if (cacheEntry.getKey().equals(key)) {
                cacheEntry.setAddTime(System.currentTimeMillis());
                return cacheEntry.getData();
            }
        }
        return null;
    }

    public synchronized Object getCloneData(String key) {
        for (int i = 0; i < this.datas.size(); i++) {
            CacheEntry cacheEntry = (CacheEntry) this.datas.get(i);
            if (cacheEntry.getKey().equals(key)) {
                cacheEntry.setAddTime(System.currentTimeMillis());
                Object cacheObj = cacheEntry.getData();
                if (cacheObj instanceof DataElement) {
                    return ((DataElement) cacheObj).clone();
                }
                throw new UnsupportedOperationException("getCloneData only support to DataElement");
            }
        }
        return null;
    }

    public static String getCacheKey(List fieldList, Context context) {
        Object fidldValue;
        StringBuffer sb = new StringBuffer(context.getName());
        Iterator fieldIt = fieldList.iterator();
        while (fieldIt.hasNext()) {
            String fieldName = (String) fieldIt.next();
            try {
                fidldValue = context.getDataValue(fieldName);
            } catch (Exception unused) {
                fidldValue = null;
            }
            if (fidldValue != null) {
                sb.append(",fieldName").append("=").append(((String) fidldValue).toLowerCase());
            }
        }
        return sb.toString();
    }

    /* loaded from: com_ynet_life_util.jar:com/ynet/life/util/DataCache$CacheEntry.class */
    private static class CacheEntry implements Serializable {
        private String key;
        private Object data;
        private long addTime = System.currentTimeMillis();

        public CacheEntry(String key, Object data) {
            this.key = key;
            this.data = data;
        }

        public String getKey() {
            return this.key;
        }

        public void setKey(String key) {
            this.key = key;
        }

        public Object getData() {
            return this.data;
        }

        public void setData(Object data) {
            this.data = data;
        }

        public long getAddTime() {
            return this.addTime;
        }

        public void setAddTime(long addTime) {
            this.addTime = addTime;
        }
    }
}
